package VMOMI::DisallowedChangeByServiceDisallowedChange;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
